﻿
-- PriorityList_Mainframe -> scrollframe -> content

local addonName, addon = ...
local L = addon.L

local mainframe_width = 500
local mainframe_height = 400
local scrollbar_width = 16
local border_size = 10
local mainframe_bg = "Interface\\GLUES\\LoadingScreens\\LoadScreenBlackTemple.blp"

local function SetDraggable(f)
 f:EnableMouse(true)
 f:SetMovable()
 f:RegisterForDrag("LeftButton")
 f:SetMinResize(100,100)
 f:SetScript("OnDragStart", function(self)  
   self:StartMoving()
  end)
  f:SetScript("OnDragStop", function(self) 
  self:StopMovingOrSizing()
 end)
end

-- Mainframe
local f = CreateFrame("Frame", "PriorityList_Mainframe", UIParent) 
PriorityList_Mainframe = f
SetDraggable(f)
f:SetPoint("CENTER")
f:SetSize(mainframe_width, mainframe_height)
local t = f:CreateTexture()
t:SetAllPoints() 
t:SetTexture(0,0,0,1)
f.background = t
f:Hide()

local function CreateListBox()
 --scrollframe (listbox)
 local scrollframe = CreateFrame("ScrollFrame", nil, f) 
 local t = scrollframe:CreateTexture() 
 t:SetAllPoints()
 t:SetTexture(0,0,0, 0.6)

 --scrollbar
 local scrollbar = CreateFrame("Slider", nil, scrollframe, "UIPanelScrollBarTemplate") 
 scrollbar:SetPoint("TOPRIGHT", scrollframe, "TOPRIGHT", 0, -6 - border_size)
 scrollbar:SetPoint("BOTTOMLEFT", scrollframe, "BOTTOMRIGHT", -scrollbar_width, 6 + border_size)
 scrollbar:SetValueStep(1)
 scrollbar.scrollStep = 1
 scrollbar:SetValue(0)
 scrollbar:SetWidth(scrollbar_width)
 scrollbar:SetScript("OnValueChanged", function (self, value) 
                                       self:GetParent():SetVerticalScroll(value) 
                                      end)
 local scrollbg = scrollbar:CreateTexture(nil, "BACKGROUND") 
 scrollbg:SetAllPoints(scrollbar)
 scrollbg:SetTexture(0, 0, 0, 0.8)
 scrollframe.scrollbar = scrollbar 

 --content frame
 local content = CreateFrame("Frame", nil, scrollframe) 
 content:SetSize(scrollframe:GetWidth() - scrollbar_width,1)
 --content:SetAllPoints()
 content:SetPoint("TOPLEFT")
 scrollbar:SetMinMaxValues(1, math.max(1,math.floor(content:GetHeight() - scrollframe:GetHeight())))
 content:EnableMouseWheel(true)
 content:EnableMouse(true)
 content:SetScript("OnMouseWheel", function(self, value)
   if value > 0 then
    scrollbar:SetValue(scrollbar:GetValue() - scrollbar:GetHeight() / 10)
   else
    scrollbar:SetValue(scrollbar:GetValue() + scrollbar:GetHeight() / 10)
   end
  end)

 local t = content:CreateTexture()
 t:SetAllPoints()
 t:SetTexture(0,0,0,0.5)
 content.background = t
 scrollframe.content = content
 scrollframe:SetScrollChild(content)
 
 scrollframe.buttons = {}
 return scrollframe
end

f.left_listbox = CreateListBox()
f.left_listbox:SetPoint("TOPLEFT", f, "TOPLEFT", border_size, -border_size)
f.left_listbox:SetPoint("BOTTOMRIGHT", f, "BOTTOMLEFT", border_size + f:GetWidth() / 2 - scrollbar_width, border_size) 
f.right_listbox = CreateListBox()
f.right_listbox:SetPoint("TOPLEFT", f, "TOPRIGHT", -border_size -f:GetWidth()/2 + scrollbar_width , -border_size)
f.right_listbox:SetPoint("BOTTOMRIGHT", -border_size, border_size) 

-- buttons constructor
local btncounter = 1
local btn_pool = {}

function addon:ResetListBoxes(...)
 table.foreach(f.left_listbox.buttons, function(k,v) table.insert(btn_pool, v) v:Hide() end)
 table.foreach(f.right_listbox.buttons, function(k,v) table.insert(btn_pool, v) v:Hide() end)
 wipe(f.left_listbox.buttons)
 wipe(f.right_listbox.buttons)
end

local function CreateListButton(listbox, s, tab, spacing)
 
 local b
 if table.getn(btn_pool) > 0 then
  b = btn_pool[1]
  table.remove(btn_pool, 1)
 else
  b = CreateFrame("BUTTON", "PriorityList_Button"..btncounter, listbox.content, "OptionsListButtonTemplate")
 end
 btncounter = btncounter + 1
 local btncount = table.getn(listbox.buttons)
 listbox.content:SetWidth(listbox:GetWidth())
 listbox.content:SetHeight(btncount * 10)
 listbox.scrollbar:SetMinMaxValues(1, math.max(1,math.floor(listbox.content:GetHeight() - listbox:GetHeight())))
 b:SetWidth(listbox:GetWidth() - scrollbar_width - spacing)
 b:SetHeight(10)
 b:SetText(s)
 b.tex = b:CreateTexture()
 b.tex:SetAllPoints()
 b.tex:SetTexture(0,0,0,0.5)
 b:SetScript("OnClick",
   function(self, button)
    if button == "LeftButton" then
     addon:PopulateListboxes(tab, spacing)
    end
   end)
 b:Show()
 if btncount == 0 then
  b:SetPoint("TOP", listbox.content, "TOP", spacing, 0)
 else
  b:SetPoint("TOP", listbox.content, "TOP", spacing, -btncount * 11)
 end
 table.insert(listbox.buttons, b)
 
 --print("Debug, buttons pool: "..table.getn(btn_pool))
 
 return b
end

function addon:InsertBtn(...)
 local t, s, tab, spacing = ...
 local listbox = t == "left" and f.left_listbox or f.right_listbox
 CreateListButton(listbox, s, tab, spacing)
end