﻿local addonName, addonTable = ...
local L = addonTable.L
local addon = PriorityList
local AceGUI = LibStub("AceGUI-3.0")

-- string colors
local LIGHT_BLUE  = "|cff00ccff"
local LIGHT_RED   = "|cffff6060"
local GREEN       = "|cff71C671"
local LIGHT_GREEN = "|cff71FF71"
local YELLOW      = "|cffffff00"
local GREY        = "|cff888888"
local GOLD        = "|cffffcc00"
local RED         = "|cffff0000"
local WHITE       = "|cffffffff"
local function AddColor(str,color)
 return color..str.."|r"
end

-- boss list tab creation
function addon:TabInit_BossList(container)
if container then
 addon.opt.frm_items = AceGUI:Create("ScrollFrame")
 addon.opt.frm_items:SetFullWidth(true)
 addon.opt.frm_items:SetFullHeight(true)
 addon.opt.frm_items:SetLayout("List")
 container:AddChild(addon.opt.frm_items)
 addon:PopulateItemsList_new()
end
end
-- boss list tab creation end

-- boss list 3 layers folding
local function generate_fold_array()
local result = {}
 table.foreach(addon.boss_drops_table, function(raid,v)
  if not result[raid] then result[raid] = {["flag"] = false} end
  for boss,i in pairs(v) do
   if not result[raid][boss] then
    result[raid][boss] = {["flag"] = false}
   end
   for diff,j in pairs(i) do
    if not result[raid][boss][diff] and diff ~= "icon" then
     result[raid][boss][diff] = {["flag"] = false}
    end
   end
  end
 end)
 return result
end

local boss_folding = generate_fold_array()
function addon:bl_bossopened(raid,boss,diff)
local result = false
 if diff then
  if boss_folding[raid][boss][diff]["flag"] then result = true end 
 elseif boss then
 if boss_folding[raid][boss]["flag"] then result = true end
 else
  if boss_folding[raid]["flag"] then result = true end
 end
 return result
end

function addon:bl_bossSet(raid,boss,diff)
 if diff then
  boss_folding[raid][boss][diff]["flag"] = not boss_folding[raid][boss][diff]["flag"]
 elseif boss then
  boss_folding[raid][boss]["flag"] = not boss_folding[raid][boss]["flag"]
 else
  boss_folding[raid]["flag"] = not boss_folding[raid]["flag"]
 end
end
--

-- boss tooltip with needers
function addon:setbosstooltip(tt, tab, tt2)
 -- avoid exceptions
 if not tab then return end
 local raid = tab[1]
 local boss = tab[2]
 local bosstable = PriorityList.boss_drops_table[raid][boss]
 if not raid or not boss or not bosstable then return end
 
 -- generate the list
 local result = {}
 
 table.foreach(bosstable, function(diff, items)
  if diff ~= "icon" then
   table.foreach(items, function(k, itemID)
    if addon.lootlist[raid] and addon.lootlist[raid][itemID] then
     local pos = 1
     table.foreach(addon.lootlist[raid][itemID], function(j, v)
      if not result[v.name] then result[v.name] = {} result[v.name].score = 0 end
      local prio = v.prio or 99
      if prio < 99 then
       if pos == 1 then
        result[v.name].score = (result[v.name].score + 10)
   elseif pos > 1 and pos < 4 then
        result[v.name].score = (result[v.name].score + 3)
       else
        result[v.name].score = (result[v.name].score + 1)
       end
       pos = pos + 1
      end
     end)
    end
   end)
  end
 end)

 local indexed = {}
 local maxscore = 0
 
 table.foreach(result, function(k,v)
  if v.score > 0 then
   table.insert(indexed, {name = k, score = v.score})
   if v.score > maxscore then maxscore = v.score end
  end
 end)
 
 table.sort(indexed, function(a,b) return a.score > b.score end)
 -- title
 tt:AddLine(LIGHT_BLUE.."Average top needers:|r")
 
 table.foreach(indexed, 
 function(k,v)
   local col = ""
   local percent = math.floor(v.score * 100 / maxscore)
   if percent > 75 then
    col = LIGHT_GREEN
   elseif percent > 25 then
    col = YELLOW
   else
    col = LIGHT_RED
   end
    --tt:AddLine(col..v.name.."|r")
    tt:AddDoubleLine(col..v.name.."|r",percent.."%")
  end)

 local noneeds = {}
 table.foreach(PLWish_List, function(k,v) 
  if not result[k] then
   table.insert(noneeds,k)
  end
 end)
 tt2:ClearLines()
 tt2:AddLine(LIGHT_RED.."No-Needers:|r")
 table.foreach(noneeds, function(k,v)
  tt2:AddLine(GREY..v.."|r")
 end)
end
--